import pygame
from pygame.locals import *
import sys
import random
from pygame import mixer
import subprocess

pygame.init()
mixer.init()

music = pygame.mixer.music.load("asset/neon-gaming-128925.mp3")
pygame.mixer.music.play()
pygame.mixer.music.set_volume(0.5)

SCREEN_WIDTH = 800
SCREEN_HEIGHT = 600

WHITE = (255, 255, 255)
BLACK = (0, 0, 0)
GRAY = (200, 200, 200)

background = pygame.image.load("asset/finishbg.png")

screen = pygame.display.set_mode((SCREEN_WIDTH, SCREEN_HEIGHT))
pygame.display.set_caption("My Pygame")

player_width = 50
player_height = 50
center_x = SCREEN_WIDTH // 2
player_x = center_x - player_width + 100
player_y = SCREEN_HEIGHT - player_height - 70
player_speed = 80

enemy_width = 50
enemy_height = 50
enemy_x = center_x + player_width - 200
enemy_y = SCREEN_HEIGHT - enemy_height - 70

custom_font = pygame.font.Font("asset/Minecraft.ttf", 27)

english_words = ["Apple", "Banana", "Cherry", "Grapes", "Carrot", "Pear", "Strawberry", "Pineapple", "Melon", 
                 "Tomato", "Potato", "Lemon", "Avocado" ]

slovak_choices = [
    ["Jablko   ", "Hruška", "Hrozno"],
    ["Banán     ", "Kivi", "Pomaranč"],
    ["Čerešňa   ", "Citrus", "Malina"],
    ["Hrozno   ", "Jahoda", "Borovica"],
    ["Mrkva   ", "Zemiak", "Cibuľa"],
    ["Hruška   ", "Citrus", "Avokádo"],
    ["Jahoda      ", "Kiwi", "Mandarínka"],
    ["Ananás   ", "Kapusta", "Kiwi"],
    ["Melón      ", "Petržlen", "Špenát"],
    ["Paradajka    ", "Brokolica", "Paprika"],
    ["Zemiak   ", "Hruška", "Kiwi"],
    ["Citron       ", "Grejprfrút", "Mandarínka"],
    ["Avokádo   ", "Mango", "Kiwi"]
]

# Shuffle the order of Slovak translations for each English word
for choices in slovak_choices:
    random.shuffle(choices)

button_width = 120
button_height = 40
margin = 10
choice_rect1 = pygame.Rect(center_x - 3 * button_width // 2 - 2 * margin, 100, button_width, button_height)
choice_rect2 = pygame.Rect(center_x - button_width // 2 - margin, 100, button_width, button_height)
choice_rect3 = pygame.Rect(center_x + button_width // 2 + margin, 100, button_width, button_height)

hovered1 = False
hovered2 = False
hovered3 = False

word_index = 0
bad_guess = False

game_time = 30
countdown = game_time
start_time = pygame.time.get_ticks()

running = True
clock = pygame.time.Clock()
while running:
    for event in pygame.event.get():
        if event.type == pygame.QUIT:
            running = False
        if event.type == pygame.MOUSEMOTION:
            hovered1 = choice_rect1.collidepoint(event.pos)
            hovered2 = choice_rect2.collidepoint(event.pos)
            hovered3 = choice_rect3.collidepoint(event.pos)
        if event.type == pygame.MOUSEBUTTONDOWN and event.button == 1:
            if choice_rect1.collidepoint(event.pos) and slovak_choices[word_index][0] == max(slovak_choices[word_index], key=len):
                word_index += 1
                player_y -= player_speed
            elif choice_rect2.collidepoint(event.pos) and slovak_choices[word_index][1] == max(slovak_choices[word_index], key=len):
                word_index += 1
                player_y -= player_speed
            elif choice_rect3.collidepoint(event.pos) and slovak_choices[word_index][2] == max(slovak_choices[word_index], key=len):
                word_index += 1
                player_y -= player_speed
            else:
                player_y += player_speed

    current_time = pygame.time.get_ticks()
    elapsed_time = current_time - start_time
    countdown = max(game_time - elapsed_time // 1000, 0)

    enemy_speed = SCREEN_HEIGHT / (game_time * 30)

    if player_y < 0:
        subprocess.Popen(["python", "winmenu.py"])
        pygame.quit()
        sys.exit()
    elif player_y > SCREEN_HEIGHT - player_height:
        player_y = SCREEN_HEIGHT - player_height - 70

    enemy_y -= enemy_speed

    screen.blit(background, (0, 0))

    player_texture = pygame.image.load("asset/carbig.png")
    screen.blit(player_texture, (player_x, player_y))
    enemy_texture = pygame.image.load("asset/carbigenemy.png")
    screen.blit(enemy_texture, (enemy_x, enemy_y))

    if word_index < len(english_words):
        english_word = english_words[word_index]
    else:
        word_index = 0

    english_text = custom_font.render(english_word, True, BLACK)
    english_rect = english_text.get_rect(center=(center_x, 50))
    screen.blit(english_text, english_rect)

    countdown_text = custom_font.render(f"Time left: {countdown} seconds", True, BLACK)
    countdown_rect = countdown_text.get_rect(center=(center_x, 80))
    screen.blit(countdown_text, countdown_rect)

    button_color = GRAY if hovered1 else WHITE
    pygame.draw.rect(screen, button_color, choice_rect1)
    button_color = GRAY if hovered2 else WHITE
    pygame.draw.rect(screen, button_color, choice_rect2)
    button_color = GRAY if hovered3 else WHITE
    pygame.draw.rect(screen, button_color, choice_rect3)

    choice_font = pygame.font.Font(None, 25)

    choices = slovak_choices[word_index]
    choice_text1 = choice_font.render(choices[0], True, BLACK)
    choice_text2 = choice_font.render(choices[1], True, BLACK)
    choice_text3 = choice_font.render(choices[2], True, BLACK)

    text_rect1 = choice_text1.get_rect(center=choice_rect1.center)
    text_rect2 = choice_text2.get_rect(center=choice_rect2.center)
    text_rect3 = choice_text3.get_rect(center=choice_rect3.center)

    screen.blit(choice_text1, text_rect1)
    screen.blit(choice_text2, text_rect2)
    screen.blit(choice_text3, text_rect3)

    if countdown == 0:
        subprocess.Popen(["python", "losemenu.py"])
        pygame.quit()
        sys.exit()

    level_text = custom_font.render("Level 1", True, BLACK)
    screen.blit(level_text, (10, 10))

    pygame.display.update()

    clock.tick(30)

pygame.quit()
sys.exit()
